﻿using System;
using System.ComponentModel;
using System.Drawing;
using System.Drawing.Imaging;
using System.IO;
using System.Reflection;
using System.Windows.Forms;
using GSensorSDK;


namespace SeismoMeter
{
    /// <summary>
    /// Seismosaur detector
    /// 2008 gerosaurus
    /// </summary>
    public partial class SeismoMain : Form
    {

        //accelerometer
        HTCGSensor mySensor = new HTCGSensor();

        double moyenne = 0;

        //env
        string appPath;
        string appDir;

        //Graphics
        Graphics gBuffer;
        Graphics gBack;
        Graphics g;

        Bitmap bmpBack;
        Bitmap bmpBuffer;
        Bitmap bmpGuanlong;

        Bitmap bmpPencil;
        ImageAttributes iaPencil;

        int ax = 0;
        int tickCount = 0;

        Pen p1;
        Pen p2;
        Pen p3; 
        Pen p4;

        Font f;
        Brush b;



        public SeismoMain()
        {
            InitializeComponent();


        }

        private Bitmap loadCompatibleBitmap(string filename, bool bg)
        {
            System.Type st = this.GetType();
            Assembly assembly = st.Assembly;
            Stream stream = assembly.GetManifestResourceStream(st.Namespace + "." + filename);

            // Get the independent bitmap from resources
            Bitmap bitmap = new Bitmap(stream);
            stream.Close();

            // Extract the transparency color from the upper 
            // left corner (a sensible common hack)
            // Note: for the full .Net Framework, specify the current 
            // PixelFormat in the Bitmap constructor too.
            Color bg_col = bitmap.GetPixel(0, 0);
            Bitmap compatible = new Bitmap(bitmap.Size.Width, bitmap.Size.Height);
            Graphics g = Graphics.FromImage(compatible);

            // Make sure the offscreen bitmap gets erased with the default
            // background color. Here Black is chosen as transparency color.
            g.Clear(Color.Black);

            // Set the color key to what the image had...
            ImageAttributes ia = new ImageAttributes();
            if (bg)
            {
                ia.SetColorKey(bg_col, bg_col);
            }
            g.DrawImage(bitmap,
                        new Rectangle(0, 0, compatible.Size.Width, compatible.Size.Height),
                        0, 0,
                        bitmap.Size.Width, bitmap.Size.Height,
                        GraphicsUnit.Pixel, ia);

            g.Dispose();
            bitmap.Dispose();

            return compatible;
        }

        private ImageAttributes getBGIA(Bitmap bitmap)
        {
            Color bg_col = bitmap.GetPixel(0, 0);
            ImageAttributes ia = new ImageAttributes();
            ia.SetColorKey(bg_col, bg_col);
            return ia;
        }

        private void timer1_Tick(object sender, EventArgs e)
        {
            tickCount++;
            drawScreen();
        }

        private void drawScreen()
        {

            int myLastPaint = Environment.TickCount;

            gBuffer.DrawImage(bmpBuffer, 0, 1);
            
            GVector gv = mySensor.GetGVector();

            moyenne = (moyenne * 5.0 + gv.Z) / 6.0;

            int x = Convert.ToInt32(this.Width / 2 + (gv.Z - moyenne) * 8 );

            if ((tickCount % 25) == 0)
            {
                gBuffer.DrawLine(p2, 0, 0, this.Width - 1, 0);
            }
            else
            {
                gBuffer.DrawLine(p3, 0, 0, this.Width - 1, 0);
                for (int i = 0; i < this.Width / 2; i += 78)
                {
                    gBuffer.DrawLine(p4, Convert.ToInt32(this.Width / 2 + i), 0, Convert.ToInt32(this.Width / 2 + i), 1);
                    gBuffer.DrawLine(p4, Convert.ToInt32(this.Width / 2 - i), 0, Convert.ToInt32(this.Width / 2 - i), 1);

                }
            }
            
            gBuffer.DrawLine(p1, ax, bmpPencil.Height+1, x, bmpPencil.Height);
            ax = x;

            Rectangle r = new Rectangle (x,0, bmpPencil.Width, bmpPencil.Height);
            gBack.DrawImage(bmpBuffer, 0, 0);
            gBack.DrawImage(bmpPencil, r, 0, 0, bmpPencil.Width, bmpPencil.Height, GraphicsUnit.Pixel, iaPencil);
            g.DrawImage(bmpBack, 0, 0);
            //g.DrawString(data.TiltZ.ToString(), f, b, 30, 30);

        }

        private void SeismoMain_Closing(object sender, CancelEventArgs e)
        {
            //HTCSensorClose(myHandle);
        }

        private void SeismoMain_Load(object sender, EventArgs e)
        {
            appPath = Assembly.GetExecutingAssembly().GetName().CodeBase;
            appDir = appPath.Substring(0, appPath.LastIndexOf("\\"));
            
            //Graphics
            g = this.CreateGraphics();

            bmpGuanlong = loadCompatibleBitmap("guanlong.JPG", false);
            
            //buffer
            bmpBuffer = new Bitmap(this.Width, this.Height);
            gBuffer = Graphics.FromImage(bmpBuffer);
            gBuffer.Clear(Color.White);
            gBuffer.DrawImage(bmpGuanlong, this.Width - bmpGuanlong.Width, this.Height - bmpGuanlong.Height);
            

            //buffer
            bmpBack = new Bitmap(this.Width, this.Height);
            gBack = Graphics.FromImage(bmpBack);
            gBack.Clear(Color.White);
            
            //pencil
            bmpPencil = loadCompatibleBitmap("pencil.GIF", false);
            iaPencil = getBGIA(bmpPencil);

            //canvas stuff init
            p1 = new Pen(Color.Black);
            p2 = new Pen(Color.FromArgb(128, 128, 192));
            p4 = new Pen(Color.FromArgb(192,192,255 ));
            p3 = new Pen(Color.White);
            f = this.Font;
            f = new Font("Verdana", 20, FontStyle.Bold);
            b = new SolidBrush(Color.Black);



            for (int i = 0; i < this.Width / 2; i += 78)
            {
                gBuffer.DrawLine(p4, Convert.ToInt32(this.Width / 2 + i), 0, Convert.ToInt32(this.Width / 2 + i), this.Height);
                gBuffer.DrawLine(p4, Convert.ToInt32(this.Width / 2 - i), 0, Convert.ToInt32(this.Width / 2 - i), this.Height);
            }

            for (int i = 0; i < this.Height; i += 25)
            {
                gBuffer.DrawLine(p2, 0, i, this.Width, i);
            }
            
            //title
            gBuffer.DrawString("Seismo", f, b, 10, this.Height - bmpGuanlong.Height);
            f = new Font("Verdana", 8, FontStyle.Regular);
            b = new SolidBrush(Color.Blue);
            gBuffer.DrawString("http://gerosaurus.free.fr", f, b, 10, this.Height - bmpGuanlong.Height + 55);

            //
            ax = Convert.ToInt32(this.Width / 2);
            
            //
            moyenne = mySensor.GetGVector().Z;

            //timer
            Ticker.Enabled = true;


        }

        private void SeismoMain_KeyDown(object sender, KeyEventArgs e)
        {
            if ((e.KeyCode == System.Windows.Forms.Keys.Up))
            {
                // Up
            }
            if ((e.KeyCode == System.Windows.Forms.Keys.Down))
            {
                // Down
            }
            if ((e.KeyCode == System.Windows.Forms.Keys.Left))
            {
                // Left
            }
            if ((e.KeyCode == System.Windows.Forms.Keys.Right))
            {
                bmpBack.Save("screenshot", ImageFormat.Gif);
            }
            if ((e.KeyCode == System.Windows.Forms.Keys.Enter))
            {
                Close();
            }

        }

    }
    
}